feijoa.models package
=====================

Submodules
----------

feijoa.models.configuration module
----------------------------------

.. automodule:: feijoa.models.configuration
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.models.experiment module
-------------------------------

.. automodule:: feijoa.models.experiment
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.models.result module
---------------------------

.. automodule:: feijoa.models.result
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.models
   :members:
   :undoc-members:
   :show-inheritance:
